@@ -674,9 +674,9 @@ class Endpoints:
             output = e.output
             if isinstance(wrapped_exception, ClientException):
                 status_code = 400
-            elif isinstance(wrapped_exception, PluginException):
-                if wrapped_exception.preset is PluginException.Preset.BAD_REQUEST:
-                    status_code = 400
+            elif isinstance(wrapped_exception, PluginException) and \
+                    wrapped_exception.preset is PluginException.Preset.BAD_REQUEST:
+                status_code = 400
             elif isinstance(wrapped_exception, ServerException):
                 # I'm unsure about this
                 status_code = 500
@@ -692,9 +692,9 @@ class Endpoints:
     def handle_wrapped_exception(wrapped_exception):
         if isinstance(wrapped_exception, (ConnectionTestException, ClientException)):
             return 400
-        elif isinstance(wrapped_exception, PluginException):
-            if wrapped_exception.preset is PluginException.Preset.BAD_REQUEST:
-                return 400
+        elif isinstance(wrapped_exception, PluginException) and \
+                wrapped_exception.preset is PluginException.Preset.BAD_REQUEST:
+            return 400
         elif isinstance(wrapped_exception, ServerException):
             return 500
         elif isinstance(wrapped_exception, NotImplementedError):
